/*
 * SPDX-FileCopyrightText: Copyright (c) 2025 NVIDIA CORPORATION & AFFILIATES
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef __gp100_dev_hubmmu_base_addendum_h__
#define __gp100_dev_hubmmu_base_addendum_h__

#define NV_HUBMMU_PRI_MMU_INVALIDATE_HUBTLB_ONLY                      NV_PFB_PRI_MMU_INVALIDATE_HUBTLB_ONLY
#define NV_HUBMMU_PRI_MMU_INVALIDATE_HUBTLB_ONLY_FALSE                NV_PFB_PRI_MMU_INVALIDATE_HUBTLB_ONLY_FALSE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_HUBTLB_ONLY_TRUE                 NV_PFB_PRI_MMU_INVALIDATE_HUBTLB_ONLY_TRUE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_REPLAY                           NV_PFB_PRI_MMU_INVALIDATE_REPLAY
#define NV_HUBMMU_PRI_MMU_INVALIDATE_REPLAY_NONE                      NV_PFB_PRI_MMU_INVALIDATE_REPLAY_NONE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_REPLAY_START                     NV_PFB_PRI_MMU_INVALIDATE_REPLAY_START
#define NV_HUBMMU_PRI_MMU_INVALIDATE_REPLAY_START_ACK_ALL             NV_PFB_PRI_MMU_INVALIDATE_REPLAY_START_ACK_ALL
#define NV_HUBMMU_PRI_MMU_INVALIDATE_REPLAY_CANCEL_TARGETED           NV_PFB_PRI_MMU_INVALIDATE_REPLAY_CANCEL_TARGETED
#define NV_HUBMMU_PRI_MMU_INVALIDATE_REPLAY_CANCEL_GLOBAL             NV_PFB_PRI_MMU_INVALIDATE_REPLAY_CANCEL_GLOBAL
#define NV_HUBMMU_PRI_MMU_INVALIDATE_SYS_MEMBAR                       NV_PFB_PRI_MMU_INVALIDATE_SYS_MEMBAR
#define NV_HUBMMU_PRI_MMU_INVALIDATE_SYS_MEMBAR_FALSE                 NV_PFB_PRI_MMU_INVALIDATE_SYS_MEMBAR_FALSE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_SYS_MEMBAR_TRUE                  NV_PFB_PRI_MMU_INVALIDATE_SYS_MEMBAR_TRUE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_ACK                              NV_PFB_PRI_MMU_INVALIDATE_ACK
#define NV_HUBMMU_PRI_MMU_INVALIDATE_ACK_NONE_REQUIRED                NV_PFB_PRI_MMU_INVALIDATE_ACK_NONE_REQUIRED
#define NV_HUBMMU_PRI_MMU_INVALIDATE_ACK_INTRANODE                    NV_PFB_PRI_MMU_INVALIDATE_ACK_INTRANODE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_ACK_GLOBALLY                     NV_PFB_PRI_MMU_INVALIDATE_ACK_GLOBALLY
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CANCEL_CLIENT_ID                 NV_PFB_PRI_MMU_INVALIDATE_CANCEL_CLIENT_ID
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CANCEL_GPC_ID                    NV_PFB_PRI_MMU_INVALIDATE_CANCEL_GPC_ID
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CANCEL_CLIENT_TYPE               NV_PFB_PRI_MMU_INVALIDATE_CANCEL_CLIENT_TYPE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CANCEL_CLIENT_TYPE_GPC           NV_PFB_PRI_MMU_INVALIDATE_CANCEL_CLIENT_TYPE_GPC
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CANCEL_CLIENT_TYPE_HUB           NV_PFB_PRI_MMU_INVALIDATE_CANCEL_CLIENT_TYPE_HUB
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CACHE_LEVEL                      NV_PFB_PRI_MMU_INVALIDATE_CACHE_LEVEL
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CACHE_LEVEL_ALL                  NV_PFB_PRI_MMU_INVALIDATE_CACHE_LEVEL_ALL
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CACHE_LEVEL_PTE_ONLY             NV_PFB_PRI_MMU_INVALIDATE_CACHE_LEVEL_PTE_ONLY
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE0           NV_PFB_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE0
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE1           NV_PFB_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE1
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE2           NV_PFB_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE2
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE3           NV_PFB_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE3
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE4           NV_PFB_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE4
#define NV_HUBMMU_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE5           NV_PFB_PRI_MMU_INVALIDATE_CACHE_LEVEL_UP_TO_PDE5
#define NV_HUBMMU_PRI_MMU_INVALIDATE_ALL_VA                           NV_PFB_PRI_MMU_INVALIDATE_ALL_VA
#define NV_HUBMMU_PRI_MMU_INVALIDATE_ALL_VA_FALSE                     NV_PFB_PRI_MMU_INVALIDATE_ALL_VA_FALSE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_ALL_VA_TRUE                      NV_PFB_PRI_MMU_INVALIDATE_ALL_VA_TRUE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_ALL_PDB                          NV_PFB_PRI_MMU_INVALIDATE_ALL_PDB
#define NV_HUBMMU_PRI_MMU_INVALIDATE_ALL_PDB_FALSE                    NV_PFB_PRI_MMU_INVALIDATE_ALL_PDB_FALSE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_ALL_PDB_TRUE                     NV_PFB_PRI_MMU_INVALIDATE_ALL_PDB_TRUE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_TRIGGER                          NV_PFB_PRI_MMU_INVALIDATE_TRIGGER
#define NV_HUBMMU_PRI_MMU_INVALIDATE_TRIGGER_FALSE                    NV_PFB_PRI_MMU_INVALIDATE_TRIGGER_FALSE
#define NV_HUBMMU_PRI_MMU_INVALIDATE_TRIGGER_TRUE                     NV_PFB_PRI_MMU_INVALIDATE_TRIGGER_TRUE

#endif // __gp100_dev_hubmmu_base_addendum_h__
